summaryrefslogtreecommitdiff
path: root/src/third_party/wiredtiger/test/format/config.c
diff options
context:
space:
mode:
Diffstat (limited to 'src/third_party/wiredtiger/test/format/config.c')
-rw-r--r--src/third_party/wiredtiger/test/format/config.c18
1 files changed, 14 insertions, 4 deletions
diff --git a/src/third_party/wiredtiger/test/format/config.c b/src/third_party/wiredtiger/test/format/config.c
index 709eb9a4a26..8d85d331c89 100644
--- a/src/third_party/wiredtiger/test/format/config.c
+++ b/src/third_party/wiredtiger/test/format/config.c
@@ -149,8 +149,11 @@ config_setup(void)
if (DATASOURCE("kvsbdb") && access(KVS_BDB_PATH, R_OK) != 0)
testutil_die(errno, "kvsbdb shared library: %s", KVS_BDB_PATH);
- /* Some data-sources don't support user-specified collations. */
- if (DATASOURCE("kvsbdb"))
+ /*
+ * Only row-store tables support collation order.
+ * Some data-sources don't support user-specified collations.
+ */
+ if (g.type != ROW || DATASOURCE("kvsbdb"))
config_single("reverse=off", 0);
/*
@@ -185,6 +188,13 @@ config_setup(void)
if (g.c_cache_minimum != 0 && g.c_cache < g.c_cache_minimum)
g.c_cache = g.c_cache_minimum;
+ /*
+ * Turn off truncate for LSM runs (some configurations with truncate
+ * always results in a timeout).
+ */
+ if (!config_is_perm("truncate") && DATASOURCE("lsm"))
+ config_single("truncate=off", 0);
+
/* Give Helium configuration a final review. */
if (DATASOURCE("helium"))
config_helium_reset();
@@ -588,7 +598,7 @@ config_pct(void)
/* Cursor modify isn't possible for fixed-length column store. */
if (g.type == FIX) {
- if (config_is_perm("modify_pct"))
+ if (config_is_perm("modify_pct") && g.c_modify_pct != 0)
testutil_die(EINVAL,
"WT_CURSOR.modify not supported by fixed-length "
"column store");
@@ -603,7 +613,7 @@ config_pct(void)
*/
if (g.c_isolation_flag == ISOLATION_READ_UNCOMMITTED) {
if (config_is_perm("isolation")) {
- if (config_is_perm("modify_pct"))
+ if (config_is_perm("modify_pct") && g.c_modify_pct != 0)
testutil_die(EINVAL,
"WT_CURSOR.modify not supported with "
"read-uncommitted transactions");